# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @   ____   _       _   ____   __   __@
# @  / ___| | |__   (_) |  _ \  \ \ / /@
# @ | |     | '_ \  | | | |_) |  \ V / @
# @ | |___  | | | | | | |  __/    | |  @ - Pretty nice ASCII logo, right?
# @  \____| |_| |_| |_| |_|       |_|  @
# @                                    @
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

# NAME - chipy_chipy
# DESCRIPTION - a horrible python module.
# AUTHOR(s) - LighTek
# VERSION - 1.0.0
# LICENSE - MIT

# MIT License

# Copyright (c) [year] [fullname]

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

#from .decodecc import decodecc # this code is broken. unimport it.

from chipy_chipy.greet import greet # who kept this test code in

from chipy_chipy.cfile import cfile # who made the filename look like something a C# / C++ syntax would use?

from chipy_chipy.dfile import dfile # again with the C# / C++ syntax looking ahh filename.

from chipy_chipy.wfile import wfile # im not even mad anymore.

from chipy_chipy.rfile import rfile #you could have just put all of the file functions in one file. probably would have been better.

from chipy_chipy.math import add # math

from chipy_chipy.math import sub # math

from chipy_chipy.math import mul # math

from chipy_chipy.math import div # math
